@@ -182,6 +182,9 @@ INVALIDPARAMETER_INVALIDSOFTDEPLOYINFO = 'InvalidParameter.InvalidSoftDeployInfo
 # Invalid `SoftInfo`.
 INVALIDPARAMETER_INVALIDSOFTINFO = 'InvalidParameter.InvalidSoftInfo'
 
+# Incorrect parameter.
+INVALIDPARAMETER_INVALIDSOFTWARE = 'InvalidParameter.InvalidSoftWare'
+
 # The software name is invalid.
 INVALIDPARAMETER_INVALIDSOFTWARENAME = 'InvalidParameter.InvalidSoftWareName'
 
